@@ -30,7 +30,7 @@ class Server(resource2.Resource, metadata.MetadataMixin):
     allow_list = True
 
     _query_mapping = resource2.QueryParameters("image", "flavor", "name",
-                                               "status", "host",
+                                               "status", "host", "all_tenants",
                                                changes_since="changes-since")
 
     #: A list of dictionaries holding links relevant to this server.
@@ -50,11 +50,15 @@ class Server(resource2.Resource, metadata.MetadataMixin):
     #: The flavor reference, as a ID or full URL, for the flavor to use for
     #: this server.
     flavor_id = resource2.Body('flavorRef')
+    #: The flavor property as returned from server.
+    flavor = resource2.Body('flavor', type=dict)
     #: An ID representing the host of this server.
     host_id = resource2.Body('hostId')
     #: The image reference, as a ID or full URL, for the image to use for
     #: this server.
     image_id = resource2.Body('imageRef')
+    #: The image property as returned from server.
+    image = resource2.Body('image', type=dict)
     #: Metadata stored for this server. *Type: dict*
     metadata = resource2.Body('metadata', type=dict)
     #: While the server is building, this value represents the percentage
@@ -76,6 +80,9 @@ class Server(resource2.Resource, metadata.MetadataMixin):
     key_name = resource2.Body('key_name')
     #: The disk configuration. Either AUTO or MANUAL.
     disk_config = resource2.Body('OS-DCF:diskConfig')
+    #: Indicates whether a configuration drive enables metadata injection.
+    #: Not all cloud providers enable this feature.
+    has_config_drive = resource2.Body('config_drive')
     #: The name of the availability zone this server is a part of.
     availability_zone = resource2.Body('OS-EXT-AZ:availability_zone')
     #: The power state of this server.
@@ -114,7 +121,7 @@ class Server(resource2.Resource, metadata.MetadataMixin):
     #: networks defined for the tenant. When you do not specify the
     #: networks parameter, the server attaches to the only network
     #: created for the current tenant.
-    networks = resource2.Body('networks', type=dict)
+    networks = resource2.Body('networks')
 
     def _action(self, session, body):
         """Preform server actions given the message body."""
@@ -136,6 +143,11 @@ class Server(resource2.Resource, metadata.MetadataMixin):
         body = {'reboot': {'type': reboot_type}}
         self._action(session, body)
 
+    def force_delete(self, session):
+        """Force delete a server."""
+        body = {'forceDelete': None}
+        self._action(session, body)
+
     def rebuild(self, session, name, admin_password,
                 preserve_ephemeral=False, image=None,
                 access_ipv4=None, access_ipv6=None,
@@ -193,6 +205,90 @@ class Server(resource2.Resource, metadata.MetadataMixin):
         body = {"removeSecurityGroup": {"name": security_group}}
         self._action(session, body)
 
+    def reset_state(self, session, state):
+        body = {"os-resetState": {"state": state}}
+        self._action(session, body)
+
+    def add_fixed_ip(self, session, network_id):
+        body = {"addFixedIp": {"networkId": network_id}}
+        self._action(session, body)
+
+    def remove_fixed_ip(self, session, address):
+        body = {"removeFixedIp": {"address": address}}
+        self._action(session, body)
+
+    def add_floating_ip(self, session, address, fixed_address=None):
+        body = {"addFloatingIp": {"address": address}}
+        if fixed_address is not None:
+            body['addFloatingIp']['fixed_address'] = fixed_address
+        self._action(session, body)
+
+    def remove_floating_ip(self, session, address):
+        body = {"removeFloatingIp": {"address": address}}
+        self._action(session, body)
+
+    def pause(self, session):
+        body = {"pause": None}
+        self._action(session, body)
+
+    def unpause(self, session):
+        body = {"unpause": None}
+        self._action(session, body)
+
+    def suspend(self, session):
+        body = {"suspend": None}
+        self._action(session, body)
+
+    def resume(self, session):
+        body = {"resume": None}
+        self._action(session, body)
+
+    def lock(self, session):
+        body = {"lock": None}
+        self._action(session, body)
+
+    def unlock(self, session):
+        body = {"unlock": None}
+        self._action(session, body)
+
+    def rescue(self, session, admin_pass=None, image_ref=None):
+        body = {"rescue": {}}
+        if admin_pass is not None:
+            body["rescue"]["adminPass"] = admin_pass
+        if image_ref is not None:
+            body["rescue"]["rescue_image_ref"] = image_ref
+        self._action(session, body)
+
+    def unrescue(self, session):
+        body = {"unrescue": None}
+        self._action(session, body)
+
+    def evacuate(self, session, host=None, admin_pass=None, force=None):
+        body = {"evacuate": {}}
+        if host is not None:
+            body["evacuate"]["host"] = host
+        if admin_pass is not None:
+            body["evacuate"]["adminPass"] = admin_pass
+        if force is not None:
+            body["evacuate"]["force"] = force
+        self._action(session, body)
+
+    def start(self, session):
+        body = {"os-start": None}
+        self._action(session, body)
+
+    def stop(self, session):
+        body = {"os-stop": None}
+        self._action(session, body)
+
+    def shelve(self, session):
+        body = {"shelve": None}
+        self._action(session, body)
+
+    def unshelve(self, session):
+        body = {"unshelve": None}
+        self._action(session, body)
+
 
 class ServerDetail(Server):
     base_path = '/servers/detail'
